/*   	
	procedure:	FillRecoveryAccountResponsibleParty.prc
	written by:    	Craig Deane
     	date written:  	September 2020
     	database:      	welcoll
     	function:      	This fills the RecoveryAccountResponsibleParty table with debtor data
     	modified by:  	Craig Deane 12/3/2020 FSD 1.4
     	changes:	Added support for PhysicalAddressEffectiveDate, MailingAddressEffectiveDate, Language, WrittenLanguage, and PersonNumberIdentifier
     	modified by:   	Craig Deane 2/2021
     	changes:	Modified to use the DebtList table to filter results
     	modified by:   	Craig Deane 3/18/2021
     	changes:       	Modified to use the new LegacyAccountNumberIdentifierFunction table valued function	
     	modified by:   	Craig Deane 4/28/2021 FSD 1.7
     	changes:	Modified the processing for Organization Name and Debtor Type. Fixed the Language processing
     	modified by:   	Craig Deane 6/10/2021 FSD 1.7
     	changes:	Made it use the Private Mail Box or Care of Address when the Street Address is blank	
    	modified by:   	Craig Deane 9/30/2021 Version 2.0
     	changes:	Changed the processing for Person Identifier and moved CIN to the end of the record
   	modified by:   	Craig Deane 10/21/2021 Version 2.0.1
     	changes:	Changed processing for Organizations 

*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountResponsibleParty'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountResponsibleParty
  END
go

create procedure dbo.FillRecoveryAccountResponsibleParty
as

declare 	@serial_type_ind	char(1),
	  	@program_status_ind char(1)

select @serial_type_ind = serial_type
  from calwin_control
 where calwin_key = 'C'

select @program_status_ind = IsNull(program_status_ind, 'N')
  from tax_intercept_control
  where tax_intercept_key = 'I'


delete RecoveryAccountResponsibleParty

insert RecoveryAccountResponsibleParty
select 	"Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Case Number" = (select case when @serial_type_ind = 'V' then substring(debt.reference_number, 5, 7) else
					substring(debt.reference_number, 3, 7) 	end),

	"Person Identifier" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then '1' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert(varchar(9), debtor.debtor_id) End,

	"Organization ID" = Case When IsNull(debtor1_name_mid_init, '') = '*' Then provider_number End,

	"Adjustment Indicator" = Case When @program_status_ind = 'Y' and IsNull(debt.program_status, case_status) = 'A' or
						@program_status_ind = 'N' and IsNull(case_status, debt.program_status) = 'A' Then 'Y' 
					Else 'N' End,

	"Bill Indicator" = Case When statement_ind = 'Y' and debtor1_statement_ind = 'Y' Then 'Y' Else 'N' End,

	"Tax Intercept Indicator" = IsNull(debtor1_ftb_intercept_ind, 'N'),

	"Responsible Party Status Date" = date_entered,

	"Delinquent Date" = delinquency_date, 

	"Debtor Type" = Case When IsNull(debtor1_name_mid_init, '') = '*' Then 'C' Else 'I' End,

	"Responsible Party First Name" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then debtor1_name_first End,

	"Responsible Party Middle Name" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then debtor1_name_mid_init End,

	"Responsible Party Last Name" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then 
					(select last_name from dbo.NameSuffixFunction(debtor1_name_last)) End, 

	"Responsible Party Suffix" = Case When IsNull(provider_number, '') = '' and IsNull(debtor1_name_mid_init, '') <> '*' Then 
					(select suffix_name from dbo.NameSuffixFunction(debtor1_name_last)) End, 

	"Responsible Party Status" = 'AC',

	"Organization Name" = Case When IsNull(debtor1_name_mid_init, '') = '*' Then debtor1_name_last End,

	"AKA First Name" = first_name,

	"AKA Middle Name" = '',

	"AKA Last Name" = (select last_name from dbo.NameSuffixFunction(last_name)),

	"AKA Suffix" = (select suffix_name from dbo.NameSuffixFunction(last_name)),

	"Coresponsible Flag" = Case When IsNull(debtor2_name_last, '') != '' Then 'Y' Else 'N' End,

	"Physical Address - Effective Date" = null,

	"Physical Address - Line 1 Address" = '',

	"Physical  Address - Line 2 Address" = '',

	"Physical  Address - City Name" = '',

	"Physical  Address- State Code" = '',

	"Physical  Address - Zip Code" = '',

	"Mailing Address - Effective Date" = dbo.AddressEffectiveDateFunction(debtor.debtor_id),

	"Mailing Address- Line 1 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor1_street_address)) Else
						Case When IsNull(debtor1_private_mailbox, '') <> '' Then debtor1_private_mailbox Else
							Case When IsNull(debtor1_care_of_address, '') <> '' Then debtor1_care_of_address End 
						End 
					    End,

	"Mailing Address- Line 2 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line2 from AddressFunction(debtor1_street_address)) End,

	"Mailing Address - City Name" = debtor1_city,

	"Mailing Address- State Code" = debtor1_state,

	"Mailing Address - Zip Code" =  debtor1_zip,

	"Phone Number - Area Code" = substring(debtor1_phone, 1, 3),

	"Phone Number" = substring(debtor1_phone, 4, 7),

	"Phone Extension Number" = '',

	"Responsible Party Date of Birth" = debtor1_dob,

	"Responsible Party SSN" = debtor1_ssn,

	"Responsible Party Driver License Number" = debtor1_drivers_license,

	"Language" = Case When IsNull((select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code), '') = '' Then '03'
			Else (select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code) End,

	"Written Language" = '',

	"Person Number Identifier" = '01',

	"CIN" = cin1

from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
INNER JOIN case_info ON case_info.reference_number = debt.reference_number
LEFT OUTER JOIN alias_names ON debt.debtor_id = alias_names.debtor_id
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number

where alias_sequence_number = (select max(alias_sequence_number)
				from alias_names
				where debtor_id = debt.debtor_id) or 
				alias_sequence_number is null

union

select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Case Number" = (select case when @serial_type_ind = 'V' then substring(debt.serial_number, 3, 7) else
					substring(debt.serial_number, 1, 7) 	end),

	"Person Identifier" = '2' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert(varchar(9), debtor.debtor_id),

	"Organization ID" = '',

	"Adjustment Indicator" = Case When @program_status_ind = 'Y' and IsNull(debt.program_status, case_status) = 'A' or
						@program_status_ind = 'N' and IsNull(case_status, debt.program_status) = 'A' Then 'Y' 
					Else 'N' End,	

	"Bill Indicator" = Case When statement_ind = 'Y' and debtor2_statement_ind = 'Y' Then 'Y' Else 'N' End,

	"Tax Intercept Indicator" = IsNull(debtor2_ftb_intercept_ind, 'N'),

	"Responsible Party Status Date" = date_entered,

	"Delinquent Date" = delinquency_date, 

	"Debtor Type" = 'I',

	"Responsible Party First Name" = debtor2_name_first,

	"Responsible Party Middle Name" = debtor2_name_mid_init,

	"Responsible Party Last Name" = (select last_name from dbo.NameSuffixFunction(debtor2_name_last)),

	"Responsible Party Suffix" = (select suffix_name from dbo.NameSuffixFunction(debtor2_name_last)),

	"Responsible Party Status" = 'AC',

	"Organization Name" = '',

	"AKA First Name" = first_name,

	"AKA Middle Name" = '',

	"AKA Last Name" = (select last_name from dbo.NameSuffixFunction(last_name)),

	"AKA Suffix" = (select suffix_name from dbo.NameSuffixFunction(last_name)),

	"Coresponsible Flag" = 'Y',

	"Physical Address - Effective Date" = null,

	"Physical Address- Line 1 Address" = '',

	"Physical Address- Line 2 Address" = '',

	"Physical Address - City Name" = '',

	"Physical Address- State Code" = '',

	"Physical Address - Zip Code" = '',

	"Mailing Address - Effective Date" = dbo.AddressEffectiveDateFunction(dbo.debtor.debtor_id),

	"Mailing Address- Line 1 Address" = Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then 
					         Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor1_street_address)) Else
						     Case When IsNull(debtor1_private_mailbox, '') <> '' Then debtor1_private_mailbox Else
						         Case When IsNull(debtor1_care_of_address, '') <> '' Then debtor1_care_of_address End 
						     End 
					         End
						 Else
						 Case When IsNull(debtor2_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor2_street_address)) Else
						     Case When IsNull(debtor2_private_mailbox, '') <> '' Then debtor2_private_mailbox Else
						     	Case When IsNull(debtor2_care_of_address, '') <> '' Then debtor2_care_of_address End 
						     End 
					         End
					     End,

	"Mailing Address- Line 2 Address" = Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then
						(select address_line2 from AddressFunction(debtor2_street_address))
						Else (select address_line2 from AddressFunction(debtor1_street_address))
					     End,

	"Mailing Address - City Name" = Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then debtor1_city Else debtor2_city End,

	"Mailing Address- State Code" = Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then debtor1_state Else debtor2_state End,

	"Mailing Address - Zip Code" =  Case When IsNull(debtor2_street_address, '') + IsNull(debtor2_care_of_address, '') + IsNull(debtor2_private_mailbox, '') = '' Then debtor1_zip Else debtor2_zip End,

	"Phone Number - Area Code" = substring(debtor2_phone, 1, 3),

	"Phone Number" = substring(debtor2_phone, 4, 7),

	"Phone Extension Number" = '',

	"Responsible Party Date of Birth" = debtor2_dob,

	"Responsible Party SSN" = debtor2_ssn,

	"Responsible Party Driver License Number" = debtor2_drivers_license,

	"Language" = Case When IsNull((select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code), '') = '' Then '03'
			Else (select calsaws_code		
			from CalSAWSLanguageCodeMap
			where CalSAWSLanguageCodeMap.vacs_code = debtor.primary_language_code) End,

	"Written Language" = '',

	"Person Number Identifier" = '02',

	"CIN" = cin2
					
from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
INNER JOIN case_info ON case_info.reference_number = debt.reference_number
LEFT OUTER JOIN alias_names ON debt.debtor_id = alias_names.debtor_id
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
where IsNull(debtor2_name_last, '') != '' and
(alias_sequence_number = (select max(alias_sequence_number)
				from alias_names
				where debtor_id = debt.debtor_id) or 
				alias_sequence_number is null)
 

update RecoveryAccountResponsibleParty
set PhysicalAddressEffectiveDate = MailingAddressEffectiveDate,
PhysicalAddressLine1Address = MailingAddressLine1Address,
PhysicalAddressLine2Address = MailingAddressLine2Address,
PhysicalAddressCityName = MailingAddressCityName,
PhysicalAddressStateCode = MailingAddressStateCode,
PhysicalAddressZipCode = MailingAddressZipCode,
WrittenLanguage = Language
            
go

grant execute on FillRecoveryAccountResponsibleParty to public
go

/*   	procedure:     	FillRecoveryAccountRepaymentTerm.prc
	written by:    	Craig Deane
     	date written:  	September 2020
     	database:      	welcoll
     	function:      	This fills the RecoveryAccountRepaymentTerm table with claim data
     	modified by:   	Craig Deane 2/2021
     	changes:	Modified to use the DebtList table to filter results
     	modified by:   	Craig Deane 3/17//2021
     	changes:       	Modified to use the new LegacyAccountNumberIdentifierFunction table valued function	
    	modified by:   	Craig Deane 9/30/2021 Version 2.0
     	changes:	Changed the processing for Person Identifier
   	modified by:   	Craig Deane 10/21/2021 Version 2.0.1
     	changes:	Changed processing for Organizations 
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountRepaymentTerm'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountRepaymentTerm
  END
go

create procedure dbo.FillRecoveryAccountRepaymentTerm
as

declare 	@serial_type_ind	char(1)


select @serial_type_ind = serial_type
  from calwin_control
 where calwin_key = 'C'

delete RecoveryAccountRepaymentTerm

insert RecoveryAccountRepaymentTerm
select "Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,
	"Case Number" = (select case when @serial_type_ind = 'V' then substring(debt.reference_number, 5, 7) else
					substring(debt.reference_number, 3, 7) 	end),
	"Person Identifier" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then '1' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert				(varchar(9), debtor.debtor_id) End,
	"Organization ID" = Case When IsNull(debtor1_name_mid_init, '') = '*' Then provider_number End,
	"Override Cause Indicator" = 'Y',
	"Repay Percent" = '000',
	"Repay Amount" = installment_amount,
	"Frequency Code" = 'MO',
	"Begin Date" = date_first_payment_due,
	"Type Code" = 'EP',
	"End Date" = date_last_payment_due,
	"Agreement Type" = '',
	"Entitlement Type" = ''
					
from debt
JOIN debtor ON debtor.debtor_id = debt.debtor_id
JOIN case_info ON case_info.reference_number = debt.reference_number
JOIN payment_plan ON payment_plan.plan_id = debt.plan_id
JOIN DebtList ON DebtList.debt_number = debt.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
             
go

grant execute on FillRecoveryAccountRepaymentTerm to public
go

/*   	
	procedure:	FillRecoveryAccountProviders.prc
	written by:    	Craig Deane
     	date written:  	June 2021
     	database:      	welcoll
     	function:      	This fills the RecoveryAccountProviders table with debtor data
    	modified by:   	Craig Deane 9/30/2021 Version 2.0
     	changes: 	Changed processing for the Organization ID
   	modified by:   	Craig Deane Version 10/21/2021 2.0.1
     	changes: 	Set ax Type Code to 'IC'. Changed the processing for Organization ID
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountProviders'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountProviders
  END
go

create procedure dbo.FillRecoveryAccountProviders
as

delete RecoveryAccountProviders

insert RecoveryAccountProviders
select 	"Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Organization ID" = Case When IsNull(debtor1_name_mid_init, '') <> '*' Then '1' + Replicate('0', 8 - Len(Convert(varchar(9), debtor.debtor_id))) + Convert				(varchar(9), debtor.debtor_id) End,

	"Organization Name" = debtor1_name_first + ' ' + debtor1_name_mid_init + ' ' + debtor1_name_last,

	"Tax Type Code"	= 'IC',

	"Tax ID Type" = 'SN',

	"Tax ID" = debtor1_ssn,

	"Physical Address - Line 1 Address" = '',

	"Physical  Address - Line 2 Address" = '',

	"Physical  Address - City Name" = '',

	"Physical  Address- State Code" = '',

	"Physical  Address - Zip Code" = '',

	"Mailing Address- Line 1 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor1_street_address)) Else
						Case When IsNull(debtor1_private_mailbox, '') <> '' Then debtor1_private_mailbox Else
							Case When IsNull(debtor1_care_of_address, '') <> '' Then debtor1_care_of_address End 
						End 
					    End,

	"Mailing Address- Line 2 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line2 from AddressFunction(debtor1_street_address)) End,

	"Mailing Address - City Name" = debtor1_city,

	"Mailing Address- State Code" = debtor1_state,

	"Mailing Address - Zip Code" =  debtor1_zip,

	"Phone Number - Area Code" = substring(debtor1_phone, 1, 3),

	"Phone Number" = substring(debtor1_phone, 4, 7),

	"Phone Extension Number" = ''

from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
where type_code in ('FOS', 'IHS', 'AAP') and
	IsNull(provider_number, '') = '' and
	IsNull(cin1, '') = '' and
	IsNull(cin2, '') = ''

update RecoveryAccountProviders
set PhysicalAddressLine1Address = MailingAddressLine1Address,
PhysicalAddressLine2Address = MailingAddressLine2Address,
PhysicalAddressCityName = MailingAddressCityName,
PhysicalAddressStateCode = MailingAddressStateCode,
PhysicalAddressZipCode = MailingAddressZipCode
            
go

grant execute on FillRecoveryAccountProviders to public
go

